summaryrefslogtreecommitdiffstats
path: root/kalarm/lib/lineedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kalarm/lib/lineedit.h')
-rw-r--r--kalarm/lib/lineedit.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kalarm/lib/lineedit.h b/kalarm/lib/lineedit.h
index 0da53683..660d4537 100644
--- a/kalarm/lib/lineedit.h
+++ b/kalarm/lib/lineedit.h
@@ -62,15 +62,15 @@ class LineEdit : public KLineEdit
enum Type { Text, Url, Emails };
/** Constructor.
* @param type The content type for the line edit.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit LineEdit(Type type, TQWidget* tqparent = 0, const char* name = 0);
+ explicit LineEdit(Type type, TQWidget* parent = 0, const char* name = 0);
/** Constructs a line edit whose content type is Text.
* @param tqparent The tqparent object of this widget.
* @param name The name of this widget.
*/
- explicit LineEdit(TQWidget* tqparent = 0, const char* name = 0);
+ explicit LineEdit(TQWidget* parent = 0, const char* name = 0);
/** Prevents the line edit's contents being selected when the widget receives focus. */
void setNoSelect() { mNoSelect = true; }
/** Sets whether the cursor should be set at the beginning or end of the text when
@@ -62,15 +62,15 @@ class LineEdit : public KLineEdit
/** Constructor.
* @param type The content type for the line edit.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/
@@ -62,15 +62,15 @@ class LineEdit : public KLineEdit
/** Constructs a line edit whose content type is Text.
- * @param tqparent The tqparent object of this widget.
+ * @param parent The parent object of this widget.
* @param name The name of this widget.
*/